/* Copyright (c) 2008-2018 Algo Communication Products Ltd. */

var browser_is_ie = (navigator.appName == "Microsoft Internet Explorer");
var window_has_focus = true;
var active_element = document.activeElement;

function onWindowFocus() {
	window_has_focus = true;
}

function onWindowBlur()	{
	if (active_element != document.activeElement) {
		active_element = document.activeElement;
		return;
	}
	window_has_focus = false;
}

if (browser_is_ie) {
	document.onfocusout = function() {
		onWindowBlur();
	}
	document.onfocusin = function() {
		onWindowFocus();
	}
} else {
	window.onblur = function() {
		onWindowBlur();
	}
	window.onfocus = function() {
		onWindowFocus();
	}
}

/*
 * XML HTTP Request based on the script from:
 *		http://www.jibbering.com/2002/4/httprequest.html
 */

var xmlhttp = false;
/*@cc_on @*/
/*@if (@_jscript_version >= 5)
// JavaScript gives us conditional compilation.
// We can cope with old IE versions and security blocked creation of objects.
try {
	xmlhttp = new ActiveXObject("Msxml2.XMLHTTP");
} catch (e) {
	try {
		xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
	} catch (E) {
		xmlhttp = false;
	}
}
@end @*/
if (!xmlhttp && typeof XMLHttpRequest!='undefined') {
	try {
		xmlhttp = new XMLHttpRequest();
	} catch (e) {
		xmlhttp = false;
	}
}
if (!xmlhttp && window.createRequest) {
	try {
		xmlhttp = window.createRequest();
	} catch (e) {
		xmlhttp = false;
	}
}

var interval_id = 0;
var timer_value = 0;

var dest_link='/';

function update_timer()
{
	if (timer_value > 0)
		timer_value--;
	document.getElementById("timer").innerHTML = timer_value;
}

function check_page()
{
	update_timer();
	xmlhttp.open("GET", "/",true);
	xmlhttp.onreadystatechange=function() {
		if (xmlhttp.readyState == 4) {
			if (xmlhttp.status == 200) {
				/* alert("URL Exists!"); */
				clearInterval(interval_id);
				window.location = dest_link;
			}
		}
	}
	xmlhttp.send(null)
}

function try_connect()
{
	clearInterval(interval_id);
	interval_id = setInterval("check_page()", 1000);
}

function reconnect(initval, delay, dest)
{
	timer_value = initval;
	dest_link = dest;
	setTimeout("try_connect()", delay * 1000);
	interval_id = setInterval("update_timer()", 1000);
}


/*
 * Form validation functions based on the script from:
 *		http://www.xs4all.nl/~sbpoley/webmatters/formval.html
 * Author: Stephen Poley
 */

var nbsp = 160;			/* non-breaking space char */
var node_text = 3;		/* DOM text node-type */
var emptyString = /^\s*$/ ;
var global_valfield;	/* retain valfield for timer thread */

/* Trim leading/trailing whitespace off string */
function trim(str)
{
	return str.replace(/^\s+|\s+$/g, '');
}


/* Delayed focus setting to get around IE bug */
function setFocusDelayed()
{
	global_valfield.focus();
}

function setfocus(valfield)
{
	/* save valfield in global variable so value retained when routine exits */
	global_valfield = valfield;
	setTimeout('setFocusDelayed()', 100);
}


/*
 * Display warn/error message in HTML element.
 * commonCheck routine must have previously been called
 * param fld: id of element in which to display message
 * param msgtype: class to give element ("ok" or "error")
 * param msg: string to display
 */
function msg(fld, msgtype, msg)
{
	var elem = document.getElementById(fld);
	if (msgtype == 'ok') {
		elem.style.display = 'none';
	} else {
		elem.style.display = "inline";
		elem.title = msg;
	}
}

/*
 * Common code for all validation routines to:
 * (a) check for older / less-equipped browsers
 * (b) check if empty fields are required
 *
 * param valfield: element to be validated
 * param infofield: id of element to receive info/error msg
 * param required: true if required
 *
 * Returns true (validation passed),
 *         false (validation failed) or
 *         proceed (don't know yet)
 */

var proceed = 2;

function commonCheck (valfield, infofield, required)
{
	if (!document.getElementById)
		return true;  /* not available on this browser, let server validate */

	if (emptyString.test(valfield.value)) {
		if (required) {
			msg(infofield, "error", "required");
			setfocus(valfield);
			return false;
		} else {
			msg(infofield, "ok");   /* OK */
			return true;
		}
	}
	return proceed;
}

/* validate IP address */
function valIp(valfield, infofield, required)
{
	var stat = commonCheck(valfield, infofield, required);
	if (stat != proceed)
		return stat;

	var tfld = trim(valfield.value);
	var ipaddr = /^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/ ;
	if (!ipaddr.test(tfld)) {
		msg(infofield, "error", "invalid address");
		setfocus(valfield);
		return false;
	} else {
		msg(infofield, "ok");
	}

	return true;
}

/* validate extension number */
function valExt(valfield, infofield, required)
{
	var stat = commonCheck(valfield, infofield, required);
	if (stat != proceed)
		return stat;

	var tfld = trim(valfield.value);
	var extnum = /^[0-9]{1,12}$/ ;
	if (!extnum.test(tfld)) {
		msg(infofield, "error", 'valid extension contains 1 to 12 digits');
		setfocus(valfield);
		return false;
	} else {
		msg(infofield, 'ok');
	}
	return true;
}

/* validate DTMF code */
function valDtmf(valfield, infofield, required)
{
	var stat = commonCheck(valfield, infofield, required);
	if (stat != proceed)
		return stat;

	var tfld = trim(valfield.value);
	var extnum = /^[0-9\#\*]{1,4}$/ ;
	if (!extnum.test(tfld)) {
		msg(infofield, "error", 'valid extension contains 1 to 4 digits');
		setfocus(valfield);
		return false;
	} else {
		msg(infofield, 'ok');
	}

	return true;
}

/* validate number */
function valNum(valfield, infofield, required)
{
	var stat = commonCheck(valfield, infofield, required);
	if (stat != proceed)
		return stat;

	var tfld = trim(valfield.value);
	var extnum = /^\d{1,8}$/ ;
	if (!extnum.test(tfld)) {
		msg(infofield, "error", "ERROR: not a valid number");
		setfocus(valfield);
		return false;
	} else {
		msg(infofield, "warn", "");
	}

	return true;
}

/* validate name */
function valName(valfield, infofield, required)
{
	var stat = commonCheck(valfield, infofield, required);
	if (stat != proceed)
		return stat;

	var tfld = trim(valfield.value);
	var extnum = /^\w{1,16}$/ ;
	if (!extnum.test(tfld)) {
		msg(infofield, "error", "ERROR: not a valid name");
		setfocus(valfield);
		return false;
	} else {
		msg(infofield, "warn", "");
	}

	return true;
}

/* validate file name */
function valFile(valfield, infofield, required)
{
	var stat = commonCheck(valfield, infofield, required);
	if (stat != proceed)
		return stat;

	var tfld = trim(valfield.value);
	if (tfld == '') {
		msg(infofield, "error", "ERROR: not a valid file name");
		setfocus(valfield);
		return false;
	} else {
		msg(infofield, "warn", "");
	}

	return true;
}

/* validate password */
function valPwd(valfield, pwdfield, infofield, required)
{
	var tfld = valfield.value;
	var pwd = document.getElementById(pwdfield).value;
	if (tfld != pwd) {
		msg(infofield, "error", "password mismatch");
		return false;
	} else {
		msg(infofield, "ok");
	}
	return true;
}

/* validate number range */
function valNumRange(valfield, infofield, required, minv, maxv)
{
	var stat = commonCheck(valfield, infofield, required);
	if (stat != proceed)
		return stat;

	var tfld = trim(valfield.value);
	var extnum = /(^-?\d\d*$)/ ;
	if (!extnum.test(tfld)) {
		msg(infofield, "error", "not a valid number");
		setfocus(valfield);
		return false;
	}
	var num = parseInt(tfld, 10);
	if (num < minv || num > maxv) {
		msg(infofield, "error", "out of range");
		return false;
	} else {
		msg(infofield, "ok");
	}
	return true;
}

function show_element(id, state)
{
	document.getElementById(id).style.display = state ? 'block' : 'none';
}

function show_class(name, state)
{
	var elements = document.getElementsByClassName(name);
	for (var i = 0; i < elements.length; i++) {
		elements[i].style.display = state ? 'inline' : 'none';
	}
}

function read_radio_value(name)
{
	var radios;

	radios = document.getElementsByName(name);

	for (var i = 0, length = radios.length; i < length; i++) {
		if (radios[i].checked)
			return radios[i].value;
	}
	return 0;
}

function read_radio_valuei(name)
{
	return parseInt(read_radio_value(name));
}
